[![PyPI version](https://badge.fury.io/py/pyEstradasPT.svg)](https://badge.fury.io/py/pyEstradasPT)

# pyEstradasPT
Python library to retrieve information from [Estradas.pt](http://estradas.pt)

## Requirements
- aiohttp
- json

## Changelog

1.0.0 First Version

## Credits
Values are obtained from [Estradas.pt](http://estradas.pt)

## Copyright

(C) 2018 Diogo Rodrigues <dpjrodrigues@gmail.com> 
